/* Smart mirror config.
 * Customized for Matej Ferencevic and Filip Novoselec.
 */

var config = {
    address: "localhost",
    port: 8080,
    ipWhitelist: ["127.0.0.1", "::ffff:127.0.0.1", "::1"],

    language: "en",
    timeFormat: 24,
    units: "metric",

    modules: [
        {
            module: "alert"
        },

        // Modules used for everyone
        {
            module: "updatenotification",
            position: "top_bar",
            classes: "default everyone"
        },
        {
            module: "clock",
            position: "top_left",
            classes: "default everyone"
        },
        {
            module: "currentweather",
            position: "top_right",
            config: {
                location: "Zagreb",
                locationID: "6618983", // Zagreb, HR
                appid: "" // zamijeniti s tokenom
            },
            classes: "default everyone"
        },
        {
            module: "weatherforecast",
            position: "top_right",
            header: "Weather Forecast",
            config: {
                location: "Zagreb",
                locationID: "6618983", // Zagreb, HR
                appid: "" // zamijeniti s tokenom
            },
            classes: "default everyone"
        },
        {
            module: "MMM-AirQuality",
            position: "top_right",
            config: {
                location: "croatia/zagreb-1/"
            },
            classes: "default everyone"
        },

        // Modules specific for Matej Ferencevic
        {
            module: "calendar",
            header: "FER kalendar",
            position: "top_left",
            config: {
                calendars: [
                    {
                        symbol: "calendar-check-o ",
                        url: "" // zamijeniti s adresom kalendara
                    }
                ]
            },
            classes: "matej"
        },
        {
            module: "MMM-CoinMarketCap",
            position: "bottom_left",
            header: "Cryptocurrencies",
            config: {
                currencies: ["bitcoin", "ethereum", "litecoin", "ripple"],
                view: "graphWithChanges"
            },
            classes: "matej"
        },
        {
            module: "MMM-RottenTomatoes",
            position: "bottom_right",
            classes: "matej"
        },
        {
            module: "newsfeed",
            position: "lower_third",
            config: {
                feeds: [
                    {
                        title: "24 sata",
                        url: "https://www.24sata.hr/feeds/aktualno.xml"
                    },
                    {
                        title: "Jutarnji",
                        url: "https://www.jutarnji.hr/rss/vijesti"
                    },
                    {
                        title: "Večernji",
                        url: "https://www.vecernji.hr/feeds/latest",
                    }
                ],
                showSourceTitle: true,
                showPublishDate: true
            },
            classes: "matej"
        },

        // Modules specific for Filip Novoselec
        {
            module: "MMM-quote-of-the-day",
            position: "lower_third",
            config: {
                language: "en",
                updateInterval: "20s"
            },
            classes: "filip"
        },
        {
            module: "MMM-Stock",
            position: "bottom_center",
            config: {
                companies: ["MSFT", "GOOG", "ORCL", "FB", "AAPL"]
            },
            classes: "filip"
        },
        {
            module: "MMM-Trello",
            position: "top_left",
            config: {
                api_key: "", // zamijeniti s tokenom
                token: "", // zamijeniti s tokenom
                list: "" // zamijeniti s tokenom
            },
            classes: "filip"
        },

        // Facial recognition module
        {
            module: "MMM-Facial-Recognition-OCV3",
            config: {
                threshold: 50,
                useUSBCam: false,
                trainingFile: "/home/pi/MagicMirror/modules/MMM-Facial-Recognition-OCV3/training.xml",
                interval: 0.5,
                logoutDelay: 5,
                users: ["matej", "filip"],
                defaultClass: "default",
                everyoneClass: "everyone",
                welcomeMessage: true
            }
        }
    ]

};

/*************** DO NOT EDIT THE LINE BELOW ***************/
if (typeof module !== "undefined") {module.exports = config;}
